import { IAccountsClientConfiguration, ITransportInterface, IAccountsClient, IdentityState } from '../interfaces';
import { Store } from 'redux';
import { IImpersonateReturn, ITokens, IUser, ICreateUser, ILoginReturn, IPassword, ILoginUserIdentity } from '@identity-stack/core';
export declare abstract class AbstractAccountsClient implements IAccountsClient {
    protected options: IAccountsClientConfiguration;
    protected transport: ITransportInterface;
    protected store: Store<any>;
    private storage;
    constructor(options: IAccountsClientConfiguration, transport: ITransportInterface, config: IAccountsClientConfiguration);
    abstract getState(): IdentityState;
    getStorageData(keyName: string): Promise<string>;
    setStorageData(keyName: string, value: any): Promise<string>;
    removeStorageData(keyName: string): Promise<string>;
    loadTokensFromStorage(): Promise<void>;
    loadOriginalTokensFromStorage(): Promise<void>;
    user(): IUser;
    impersonate(username: string): Promise<IImpersonateReturn>;
    stopImpersonation(): Promise<void>;
    isImpersonated(): boolean;
    originalTokens(): ITokens;
    tokens(): ITokens;
    clearTokens(): Promise<void>;
    storeTokens(tokens: ITokens): Promise<void>;
    storeOriginalTokens(tokens: ITokens): Promise<void>;
    clearUser(): void;
    resumeSession(): Promise<void>;
    refreshSession(): Promise<void>;
    createUser(user: ICreateUser, callback?: (err?: Error) => void): Promise<void>;
    loginWithPassword(user: ILoginUserIdentity, password: IPassword, callback?: (err?: Error, res?: ILoginReturn) => void): Promise<ILoginReturn>;
    loggingIn(): boolean;
    isLoading(): boolean;
    logout(callback: (err?: Error) => void): Promise<void>;
    verifyEmail(token: string): Promise<void>;
    resetPassword(token: string, newPassword: string): Promise<void>;
    requestPasswordReset(email: string): Promise<void>;
    requestVerificationEmail(email: string): Promise<void>;
}
